@@ -158,9 +158,9 @@ gchar* create_tags_string(const GSList* tags)
     return result;
 }
 
-static gboolean description_regex_cb (const GMatchInfo *info,
-                                      GString          *res,
-                                      gpointer          data)
+static gboolean replace_from_hash_table (const GMatchInfo *info,
+                                         GString          *res,
+                                         gpointer          data)
 {
     gchar *match;
     gchar *r;
@@ -185,13 +185,25 @@ static gchar* unescape_basic_html_entities(const gchar* description)
     g_hash_table_insert (hashTable, "&quot;", "\"");
     g_hash_table_insert (hashTable, "&apos;", "'");
 
-    result= g_regex_replace_eval (regex, description, -1, 0, 0, description_regex_cb, hashTable, NULL);
+    result= g_regex_replace_eval (regex, description, -1, 0, 0, replace_from_hash_table, hashTable, NULL);
     g_hash_table_destroy (hashTable);
     g_regex_unref(regex);
 
     return result;
 }
 
+static gchar* replace_slash_slash_space_with_newlines(const gchar* description)
+{
+    gchar *result;
+    GRegex *regex= g_regex_new("// ", 0, 0, NULL);
+    GHashTable *hashTable= g_hash_table_new (g_str_hash, g_str_equal);
+
+    result= g_regex_replace_literal(regex, description, -1, 0, "\n", 0, NULL);
+    g_regex_unref(regex);
+
+    return result;
+}
+
 struct Upload_s
 {
     SharingTransfer* transfer;
@@ -244,8 +256,10 @@ gboolean send_media_as_blip(BlipFoto blip,
     if (description && strlen(description) > 0)
     {
         gchar* unescaped= unescape_basic_html_entities(description);
-        blip_entry_set_description(entry, unescaped);
+        gchar* newlinehack= replace_slash_slash_space_with_newlines(unescaped);
         g_free(unescaped);
+        blip_entry_set_description(entry, newlinehack);
+        g_free(newlinehack);
     }
 
     const gchar* fullpath= sharing_entry_media_get_localpath(upload->media);
